from typing import TYPE_CHECKING, Any

from ..client.default import Default
from ..types import ChatIdUnion, InlineKeyboardMarkup, MessageEntity
from .base import TelegramMethod


class EditEphemeralMessageCaption(TelegramMethod[bool]):
    """
    Use this method to edit the caption of an ephemeral message. Note that it is not guaranteed that the user will receive the message edit event, especially if they are offline. On success, :code:`True` is returned.

    Source: https://core.telegram.org/bots/api#editephemeralmessagecaption
    """

    __returning__ = bool
    __api_method__ = "editEphemeralMessageCaption"

    chat_id: ChatIdUnion
    """Unique identifier for the target chat or username of the target supergroup in the format :code:`@username`"""
    receiver_user_id: int
    """Identifier of the user who received the message"""
    ephemeral_message_id: int
    """Identifier of the ephemeral message to edit"""
    caption: str | None = None
    """New caption of the message, 0-1024 characters after entities parsing"""
    parse_mode: str | Default | None = Default("parse_mode")
    """Mode for parsing entities in the message caption. See `formatting options <https://core.telegram.org/bots/api#formatting-options>`_ for more details"""
    caption_entities: list[MessageEntity] | None = None
    """A JSON-serialized list of special entities that appear in the caption, which can be specified instead of *parse_mode*"""
    reply_markup: InlineKeyboardMarkup | None = None
    """A JSON-serialized object for an `inline keyboard <https://core.telegram.org/bots/features#inline-keyboards>`_"""
    show_caption_above_media: bool | Default | None = Default("show_caption_above_media")
    """Pass :code:`True` if the caption must be shown above the message media. Supported only for animation, photo and video messages"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            chat_id: ChatIdUnion,
            receiver_user_id: int,
            ephemeral_message_id: int,
            caption: str | None = None,
            parse_mode: str | Default | None = Default("parse_mode"),
            caption_entities: list[MessageEntity] | None = None,
            reply_markup: InlineKeyboardMarkup | None = None,
            show_caption_above_media: bool | Default | None = Default("show_caption_above_media"),
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(
                chat_id=chat_id,
                receiver_user_id=receiver_user_id,
                ephemeral_message_id=ephemeral_message_id,
                caption=caption,
                parse_mode=parse_mode,
                caption_entities=caption_entities,
                reply_markup=reply_markup,
                show_caption_above_media=show_caption_above_media,
                **__pydantic_kwargs,
            )



from __future__ import annotations

from typing import TYPE_CHECKING, Any, Literal

from ..enums import InputRichBlockType
from .input_rich_block import InputRichBlock

if TYPE_CHECKING:
    from .rich_message_button import RichMessageButton


class InputRichBlockButtons(InputRichBlock):
    """
    A block containing a list of buttons that are shown in one row, corresponding to the custom HTML tag :code:`<tg-button-row>`.

    Source: https://core.telegram.org/bots/api#inputrichblockbuttons
    """

    type: Literal[InputRichBlockType.BUTTONS] = InputRichBlockType.BUTTONS
    """Type of the block, always 'buttons'"""
    buttons: list[RichMessageButton]
    """List of 1-8 buttons to send"""
    align: str | None = None
    """*Optional*. Horizontal alignment of the buttons. Currently, must be one of 'left', 'center', or 'right'"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            type: Literal[InputRichBlockType.BUTTONS] = InputRichBlockType.BUTTONS,
            buttons: list[RichMessageButton],
            align: str | None = None,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(type=type, buttons=buttons, align=align, **__pydantic_kwargs)



from __future__ import annotations

from typing import TYPE_CHECKING, Any, Literal

from ..enums import RichBlockType
from .rich_block import RichBlock

if TYPE_CHECKING:
    from .document import Document
    from .rich_block_caption import RichBlockCaption


class RichBlockDocument(RichBlock):
    """
    A block with a general file, corresponding to the custom HTML tag :code:`<tg-document>`.

    Source: https://core.telegram.org/bots/api#richblockdocument
    """

    type: Literal[RichBlockType.DOCUMENT] = RichBlockType.DOCUMENT
    """Type of the block, always 'document'"""
    document: Document
    """The document"""
    caption: RichBlockCaption | None = None
    """*Optional*. Caption of the block"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            type: Literal[RichBlockType.DOCUMENT] = RichBlockType.DOCUMENT,
            document: Document,
            caption: RichBlockCaption | None = None,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(type=type, document=document, caption=caption, **__pydantic_kwargs)



from __future__ import annotations

from typing import TYPE_CHECKING, Any

from .base import MutableTelegramObject

if TYPE_CHECKING:
    from .inline_keyboard_button import InlineKeyboardButton


class InlineKeyboardMarkup(MutableTelegramObject):
    """
    This object represents an `inline keyboard <https://core.telegram.org/bots/features#inline-keyboards>`_ that appears right next to the message it belongs to.

    Source: https://core.telegram.org/bots/api#inlinekeyboardmarkup
    """

    inline_keyboard: list[list[InlineKeyboardButton]]
    """Array of button rows, each represented by an Array of :class:`aiogram.types.inline_keyboard_button.InlineKeyboardButton` objects"""
    force_reply: bool | None = None
    """*Optional*. Pass :code:`True` if the reply interface must be shown to the user, as if they had manually selected the bot's message and tapped 'Reply'. The value of the field can't be changed when the inline keyboard is edited"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            inline_keyboard: list[list[InlineKeyboardButton]],
            force_reply: bool | None = None,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(
                inline_keyboard=inline_keyboard, force_reply=force_reply, **__pydantic_kwargs
            )



from typing import TypeAlias

from .input_media_animation import InputMediaAnimation
from .input_media_audio import InputMediaAudio
from .input_media_document import InputMediaDocument
from .input_media_photo import InputMediaPhoto
from .input_media_video import InputMediaVideo
from .input_media_voice_note import InputMediaVoiceNote

InputRichMessageMediaUnion: TypeAlias = (
    InputMediaAnimation
    | InputMediaAudio
    | InputMediaDocument
    | InputMediaPhoto
    | InputMediaVideo
    | InputMediaVoiceNote
)



from enum import Enum


class BotSubscriptionUpdatedState(str, Enum):
    """
    This object contains information about changes to a user payment subscription toward the current bot.

    Source: https://core.telegram.org/bots/api#botsubscriptionupdated
    """

    CANCELED = "canceled"
    ACTIVE = "active"
    FAILED = "failed"



from __future__ import annotations

from typing import TYPE_CHECKING, Any, Literal

from ..enums import RichBlockType
from .rich_block import RichBlock

if TYPE_CHECKING:
    from .rich_text_union import RichTextUnion


class RichBlockExpandableBlockQuotation(RichBlock):
    """
    A block quotation, corresponding to the HTML tag :code:`<blockquote>` with custom attribute :code:`"collapsed"`.

    Source: https://core.telegram.org/bots/api#richblockexpandableblockquotation
    """

    type: Literal[RichBlockType.EXPANDABLE_BLOCKQUOTE] = RichBlockType.EXPANDABLE_BLOCKQUOTE
    """Type of the block, always 'expandable_blockquote'"""
    text: RichTextUnion
    """Content of the block"""
    credit: RichTextUnion | None = None
    """*Optional*. Credit of the block"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            type: Literal[
                RichBlockType.EXPANDABLE_BLOCKQUOTE
            ] = RichBlockType.EXPANDABLE_BLOCKQUOTE,
            text: RichTextUnion,
            credit: RichTextUnion | None = None,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(type=type, text=text, credit=credit, **__pydantic_kwargs)



from __future__ import annotations

from typing import TYPE_CHECKING, Any, Literal

from ..enums import InputRichBlockType
from .base import TelegramObject
from .input_rich_block import InputRichBlock

if TYPE_CHECKING:
    from .input_rich_block_union import InputRichBlockUnion
    from .rich_text_union import RichTextUnion


class InputRichBlockDetails(InputRichBlock):
    """
    An expandable block for details disclosure, corresponding to the HTML tag :code:`<details>`.

    Source: https://core.telegram.org/bots/api#inputrichblockdetails
    """

    type: Literal[InputRichBlockType.DETAILS] = InputRichBlockType.DETAILS
    """Type of the block, always 'details'"""
    summary: RichTextUnion
    """Always shown summary of the block"""
    blocks: list[InputRichBlockUnion]
    """Content of the block"""
    is_open: bool | None = None
    """*Optional*. Pass :code:`True` if the content of the block is visible by default"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            type: Literal[InputRichBlockType.DETAILS] = InputRichBlockType.DETAILS,
            summary: RichTextUnion,
            blocks: list[InputRichBlockUnion],
            is_open: bool | None = None,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(
                type=type, summary=summary, blocks=blocks, is_open=is_open, **__pydantic_kwargs
            )



from __future__ import annotations

from typing import TYPE_CHECKING, Any, Literal

from ..enums import RichBlockType
from .base import TelegramObject
from .rich_block import RichBlock

if TYPE_CHECKING:
    from .rich_text import RichText
    from .rich_text_union import RichTextUnion


class RichBlockPreformatted(RichBlock):
    """
    A preformatted text block, corresponding to the nested HTML tags :code:`<pre>` and :code:`<code>`.

    Source: https://core.telegram.org/bots/api#richblockpreformatted
    """

    type: Literal[RichBlockType.PRE] = RichBlockType.PRE
    """Type of the block, always 'pre'"""
    text: RichTextUnion
    """Text of the block"""
    language: str | None = None
    """*Optional*. The programming language of the text"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            type: Literal[RichBlockType.PRE] = RichBlockType.PRE,
            text: RichTextUnion,
            language: str | None = None,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(type=type, text=text, language=language, **__pydantic_kwargs)



from typing import TYPE_CHECKING, Any

from .base import TelegramObject


class EphemeralMessageParameters(TelegramObject):
    """


    Source: https://core.telegram.org/bots/api#ephemeralmessageparameters
    """

    receiver_user_id: int
    """Identifier of the user who will receive the message. It is not guaranteed that the user will receive the message, especially if they are offline. See `here <https://core.telegram.org/bots/api#ephemeral-messages-and-commands>`_ for more details"""
    callback_query_id: str | None = None
    """*Optional*. Identifier of the callback query which triggered the message, if any"""
    replace_callback_query_message: bool | None = None
    """*Optional*. Pass :code:`True` if the ephemeral message must be shown in place of the original message. Must be :code:`False` for callback queries from ephemeral messages, which must be edited using regular *editEphemeralMessage…* methods"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            receiver_user_id: int,
            callback_query_id: str | None = None,
            replace_callback_query_message: bool | None = None,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(
                receiver_user_id=receiver_user_id,
                callback_query_id=callback_query_id,
                replace_callback_query_message=replace_callback_query_message,
                **__pydantic_kwargs,
            )



from .base import TelegramObject


class InputRichBlock(TelegramObject):
    """
    This object represents a block in a rich formatted message to be sent. Currently, it can be any of the following types:

     - :class:`aiogram.types.input_rich_block_paragraph.InputRichBlockParagraph`
     - :class:`aiogram.types.input_rich_block_section_heading.InputRichBlockSectionHeading`
     - :class:`aiogram.types.input_rich_block_preformatted.InputRichBlockPreformatted`
     - :class:`aiogram.types.input_rich_block_footer.InputRichBlockFooter`
     - :class:`aiogram.types.input_rich_block_divider.InputRichBlockDivider`
     - :class:`aiogram.types.input_rich_block_mathematical_expression.InputRichBlockMathematicalExpression`
     - :class:`aiogram.types.input_rich_block_anchor.InputRichBlockAnchor`
     - :class:`aiogram.types.input_rich_block_list.InputRichBlockList`
     - :class:`aiogram.types.input_rich_block_block_quotation.InputRichBlockBlockQuotation`
     - :class:`aiogram.types.input_rich_block_expandable_block_quotation.InputRichBlockExpandableBlockQuotation`
     - :class:`aiogram.types.input_rich_block_pull_quotation.InputRichBlockPullQuotation`
     - :class:`aiogram.types.input_rich_block_collage.InputRichBlockCollage`
     - :class:`aiogram.types.input_rich_block_slideshow.InputRichBlockSlideshow`
     - :class:`aiogram.types.input_rich_block_table.InputRichBlockTable`
     - :class:`aiogram.types.input_rich_block_details.InputRichBlockDetails`
     - :class:`aiogram.types.input_rich_block_map.InputRichBlockMap`
     - :class:`aiogram.types.input_rich_block_buttons.InputRichBlockButtons`
     - :class:`aiogram.types.input_rich_block_animation.InputRichBlockAnimation`
     - :class:`aiogram.types.input_rich_block_audio.InputRichBlockAudio`
     - :class:`aiogram.types.input_rich_block_document.InputRichBlockDocument`
     - :class:`aiogram.types.input_rich_block_photo.InputRichBlockPhoto`
     - :class:`aiogram.types.input_rich_block_video.InputRichBlockVideo`
     - :class:`aiogram.types.input_rich_block_voice_note.InputRichBlockVoiceNote`
     - :class:`aiogram.types.input_rich_block_thinking.InputRichBlockThinking`

    Source: https://core.telegram.org/bots/api#inputrichblock
    """



from __future__ import annotations

from typing import TYPE_CHECKING, Any

from ..types import ChatIdUnion, InlineKeyboardMarkup, Message
from .base import TelegramMethod


class EditMessageReplyMarkup(TelegramMethod[Message | bool]):
    """
    Use this method to edit only the reply markup of messages. On success, if the edited message is not an inline message, the edited :class:`aiogram.types.message.Message` is returned, otherwise :code:`True` is returned. Note that business messages that were not sent by the bot and do not contain an inline keyboard can only be edited within **48 hours** from the time they were sent.

    Source: https://core.telegram.org/bots/api#editmessagereplymarkup
    """

    __returning__ = Message | bool
    __api_method__ = "editMessageReplyMarkup"

    business_connection_id: str | None = None
    """Unique identifier of the business connection on behalf of which the message to be edited was sent"""
    chat_id: ChatIdUnion | None = None
    """Required if *inline_message_id* is not specified. Unique identifier for the target chat or username of the target bot, supergroup or channel in the format :code:`@username`"""
    message_id: int | None = None
    """Required if *inline_message_id* is not specified. Identifier of the message to edit"""
    inline_message_id: str | None = None
    """Required if *chat_id* and *message_id* are not specified. Identifier of the inline message"""
    reply_markup: InlineKeyboardMarkup | None = None
    """A JSON-serialized object for an `inline keyboard <https://core.telegram.org/bots/features#inline-keyboards>`_"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            business_connection_id: str | None = None,
            chat_id: ChatIdUnion | None = None,
            message_id: int | None = None,
            inline_message_id: str | None = None,
            reply_markup: InlineKeyboardMarkup | None = None,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(
                business_connection_id=business_connection_id,
                chat_id=chat_id,
                message_id=message_id,
                inline_message_id=inline_message_id,
                reply_markup=reply_markup,
                **__pydantic_kwargs,
            )



from typing import TYPE_CHECKING, Any

from ..types import ChatIdUnion
from .base import TelegramMethod


class DeleteEphemeralMessage(TelegramMethod[bool]):
    """
    Use this method to delete an ephemeral message. Note that it is not guaranteed that the user will receive the message deletion event, especially if they are offline. Returns :code:`True` on success.

    Source: https://core.telegram.org/bots/api#deleteephemeralmessage
    """

    __returning__ = bool
    __api_method__ = "deleteEphemeralMessage"

    chat_id: ChatIdUnion
    """Unique identifier for the target chat or username of the target supergroup in the format :code:`@username`"""
    receiver_user_id: int
    """Identifier of the user who received the message"""
    ephemeral_message_id: int
    """Identifier of the ephemeral message to delete"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            chat_id: ChatIdUnion,
            receiver_user_id: int,
            ephemeral_message_id: int,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(
                chat_id=chat_id,
                receiver_user_id=receiver_user_id,
                ephemeral_message_id=ephemeral_message_id,
                **__pydantic_kwargs,
            )



from typing import TYPE_CHECKING, Any

from ..types import ChatIdUnion, InlineKeyboardMarkup, InputMediaUnion
from .base import TelegramMethod


class EditEphemeralMessageMedia(TelegramMethod[bool]):
    """
    Use this method to edit the media of an ephemeral message. Note that it is not guaranteed that the user will receive the message edit event, especially if they are offline. On success, :code:`True` is returned.

    Source: https://core.telegram.org/bots/api#editephemeralmessagemedia
    """

    __returning__ = bool
    __api_method__ = "editEphemeralMessageMedia"

    chat_id: ChatIdUnion
    """Unique identifier for the target chat or username of the target supergroup in the format :code:`@username`"""
    receiver_user_id: int
    """Identifier of the user who received the message"""
    ephemeral_message_id: int
    """Identifier of the ephemeral message to edit"""
    media: InputMediaUnion
    """A JSON-serialized object for the new media content of the message"""
    reply_markup: InlineKeyboardMarkup | None = None
    """A JSON-serialized object for an `inline keyboard <https://core.telegram.org/bots/features#inline-keyboards>`_"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            chat_id: ChatIdUnion,
            receiver_user_id: int,
            ephemeral_message_id: int,
            media: InputMediaUnion,
            reply_markup: InlineKeyboardMarkup | None = None,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(
                chat_id=chat_id,
                receiver_user_id=receiver_user_id,
                ephemeral_message_id=ephemeral_message_id,
                media=media,
                reply_markup=reply_markup,
                **__pydantic_kwargs,
            )



from __future__ import annotations

from typing import TYPE_CHECKING, Any

from .base import TelegramObject

if TYPE_CHECKING:
    from .input_rich_block import InputRichBlock
    from .input_rich_block_union import InputRichBlockUnion
    from .input_rich_message_media import InputRichMessageMedia


class InputRichMessage(TelegramObject):
    """
    Describes a rich message to be sent. Exactly **one** of the fields *html*, *markdown*, or *blocks* must be used.

    Source: https://core.telegram.org/bots/api#inputrichmessage
    """

    html: str | None = None
    """*Optional*. Content of the rich message to send described using HTML formatting. See `rich message formatting options <https://core.telegram.org/bots/api#rich-message-formatting-options>`_ for more details. Use *media* field to specify the media used in the message"""
    markdown: str | None = None
    """*Optional*. Content of the rich message to send described using Markdown formatting. See `rich message formatting options <https://core.telegram.org/bots/api#rich-message-formatting-options>`_ for more details. Use *media* field to specify the media used in the message"""
    is_rtl: bool | None = None
    """*Optional*. Pass :code:`True` if the rich message must be shown right-to-left"""
    skip_entity_detection: bool | None = None
    """*Optional*. Pass :code:`True` to skip automatic detection of entities (e.g., URLs, email addresses, username mentions, hashtags, cashtags, bot commands, or phone numbers) in the text"""
    blocks: list[InputRichBlockUnion] | None = None
    """*Optional*. Content of the rich message to send described as a list of blocks"""
    media: list[InputRichMessageMedia] | None = None
    """*Optional*. List of media that are specified in the *markdown* or *html* fields using :code:`tg://photo?id=`, :code:`tg://video?id=`, :code:`tg://document?id=`, and :code:`tg://audio?id=` links"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            html: str | None = None,
            markdown: str | None = None,
            is_rtl: bool | None = None,
            skip_entity_detection: bool | None = None,
            blocks: list[InputRichBlockUnion] | None = None,
            media: list[InputRichMessageMedia] | None = None,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(
                html=html,
                markdown=markdown,
                is_rtl=is_rtl,
                skip_entity_detection=skip_entity_detection,
                blocks=blocks,
                media=media,
                **__pydantic_kwargs,
            )



from __future__ import annotations

from typing import TYPE_CHECKING, Any

from ..types import BotShortDescription
from .base import TelegramMethod


class GetMyShortDescription(TelegramMethod[BotShortDescription]):
    """
    Use this method to get the current bot short description for the given user language. Returns :class:`aiogram.types.bot_short_description.BotShortDescription` on success.

    Source: https://core.telegram.org/bots/api#getmyshortdescription
    """

    __returning__ = BotShortDescription
    __api_method__ = "getMyShortDescription"

    language_code: str | None = None
    """A two-letter ISO 639-1 language code or an empty string"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__, *, language_code: str | None = None, **__pydantic_kwargs: Any
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(language_code=language_code, **__pydantic_kwargs)



from __future__ import annotations

from typing import TYPE_CHECKING, Any

from .base import TelegramObject

if TYPE_CHECKING:
    from .chat import Chat


class MessageGenerationStopped(TelegramObject):
    """
    This object describes an update about a user stopping message generation.

    Source: https://core.telegram.org/bots/api#messagegenerationstopped
    """

    chat: Chat
    """Chat in which the message is generated"""
    draft_id: int
    """Unique identifier of the message draft which was stopped"""
    message_thread_id: int | None = None
    """*Optional*. Unique identifier of the message thread in which the message is generated"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            chat: Chat,
            draft_id: int,
            message_thread_id: int | None = None,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(
                chat=chat,
                draft_id=draft_id,
                message_thread_id=message_thread_id,
                **__pydantic_kwargs,
            )



from __future__ import annotations

from typing import TYPE_CHECKING, Any

from .base import TelegramObject

if TYPE_CHECKING:
    from .community import Community


class CommunityChatAdded(TelegramObject):
    """
    Describes a service message about a chat or a bot being added to a community.

    Source: https://core.telegram.org/bots/api#communitychatadded
    """

    community: Community
    """The new community to which the chat or the bot belongs"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__, *, community: Community, **__pydantic_kwargs: Any
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(community=community, **__pydantic_kwargs)



from __future__ import annotations

from typing import TYPE_CHECKING, Any, Literal

from ..enums import RichTextType
from .rich_text import RichText

if TYPE_CHECKING:
    from .rich_message_button import RichMessageButton


class RichTextButton(RichText):
    """
    A button.

    Source: https://core.telegram.org/bots/api#richtextbutton
    """

    type: Literal[RichTextType.BUTTON] = RichTextType.BUTTON
    """Type of the rich text, always 'button'"""
    button: RichMessageButton
    """The button"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            type: Literal[RichTextType.BUTTON] = RichTextType.BUTTON,
            button: RichMessageButton,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(type=type, button=button, **__pydantic_kwargs)



from __future__ import annotations

from typing import TYPE_CHECKING, Any

from .base import TelegramObject

if TYPE_CHECKING:
    from .input_rich_message_media_union import InputRichMessageMediaUnion


class InputRichMessageMedia(TelegramObject):
    """
    Describes a media element embedded in an outgoing rich message.

    Source: https://core.telegram.org/bots/api#inputrichmessagemedia
    """

    id: str
    """Unique identifier of the media used in a :code:`tg://photo?id=`, :code:`tg://video?id=`, :code:`tg://document?id=`, or :code:`tg://audio?id=` link. 1-64 characters, only :code:`A-Z`, :code:`a-z`, :code:`0-9`, :code:`_` and :code:`-` are allowed"""
    media: InputRichMessageMediaUnion
    """The media to be sent. Everything except the media itself and its properties is ignored"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            id: str,
            media: InputRichMessageMediaUnion,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(id=id, media=media, **__pydantic_kwargs)



from .base import TelegramObject


class CommunityChatRemoved(TelegramObject):
    """
    Describes a service message about a chat or a bot being removed from a community. Currently holds no information.

    Source: https://core.telegram.org/bots/api#communitychatremoved
    """



from typing import TYPE_CHECKING, Any

from ..client.default import Default
from ..types import (
    ChatIdUnion,
    InlineKeyboardMarkup,
    InputRichMessage,
    LinkPreviewOptions,
    MessageEntity,
)
from .base import TelegramMethod


class EditEphemeralMessageText(TelegramMethod[bool]):
    """
    Use this method to edit an ephemeral text or rich message. Note that it is not guaranteed that the user will receive the message edit event, especially if they are offline. On success, :code:`True` is returned.

    Source: https://core.telegram.org/bots/api#editephemeralmessagetext
    """

    __returning__ = bool
    __api_method__ = "editEphemeralMessageText"

    chat_id: ChatIdUnion
    """Unique identifier for the target chat or username of the target supergroup in the format :code:`@username`"""
    receiver_user_id: int
    """Identifier of the user who received the message"""
    ephemeral_message_id: int
    """Identifier of the ephemeral message to edit"""
    text: str | None = None
    """New text of the message, 1-4096 characters after entity parsing; required if *rich_message* isn't specified"""
    parse_mode: str | Default | None = Default("parse_mode")
    """Mode for parsing entities in the message text. See `formatting options <https://core.telegram.org/bots/api#formatting-options>`_ for more details"""
    entities: list[MessageEntity] | None = None
    """A JSON-serialized list of special entities that appear in message text, which can be specified instead of *parse_mode*"""
    link_preview_options: LinkPreviewOptions | Default | None = Default("link_preview")
    """Link preview generation options for the message"""
    reply_markup: InlineKeyboardMarkup | None = None
    """A JSON-serialized object for an `inline keyboard <https://core.telegram.org/bots/features#inline-keyboards>`_"""
    rich_message: InputRichMessage | None = None
    """New rich content of the message; required if *text* isn't specified"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            chat_id: ChatIdUnion,
            receiver_user_id: int,
            ephemeral_message_id: int,
            text: str | None = None,
            parse_mode: str | Default | None = Default("parse_mode"),
            entities: list[MessageEntity] | None = None,
            link_preview_options: LinkPreviewOptions | Default | None = Default("link_preview"),
            reply_markup: InlineKeyboardMarkup | None = None,
            rich_message: InputRichMessage | None = None,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(
                chat_id=chat_id,
                receiver_user_id=receiver_user_id,
                ephemeral_message_id=ephemeral_message_id,
                text=text,
                parse_mode=parse_mode,
                entities=entities,
                link_preview_options=link_preview_options,
                reply_markup=reply_markup,
                rich_message=rich_message,
                **__pydantic_kwargs,
            )



from typing import Annotated, TypeAlias

from pydantic import Field

from .input_rich_block_anchor import InputRichBlockAnchor
from .input_rich_block_animation import InputRichBlockAnimation
from .input_rich_block_audio import InputRichBlockAudio
from .input_rich_block_block_quotation import InputRichBlockBlockQuotation
from .input_rich_block_buttons import InputRichBlockButtons
from .input_rich_block_collage import InputRichBlockCollage
from .input_rich_block_details import InputRichBlockDetails
from .input_rich_block_divider import InputRichBlockDivider
from .input_rich_block_document import InputRichBlockDocument
from .input_rich_block_expandable_block_quotation import InputRichBlockExpandableBlockQuotation
from .input_rich_block_footer import InputRichBlockFooter
from .input_rich_block_list import InputRichBlockList
from .input_rich_block_map import InputRichBlockMap
from .input_rich_block_mathematical_expression import InputRichBlockMathematicalExpression
from .input_rich_block_paragraph import InputRichBlockParagraph
from .input_rich_block_photo import InputRichBlockPhoto
from .input_rich_block_preformatted import InputRichBlockPreformatted
from .input_rich_block_pull_quotation import InputRichBlockPullQuotation
from .input_rich_block_section_heading import InputRichBlockSectionHeading
from .input_rich_block_slideshow import InputRichBlockSlideshow
from .input_rich_block_table import InputRichBlockTable
from .input_rich_block_thinking import InputRichBlockThinking
from .input_rich_block_video import InputRichBlockVideo
from .input_rich_block_voice_note import InputRichBlockVoiceNote

InputRichBlockUnion: TypeAlias = Annotated[
    InputRichBlockParagraph
    | InputRichBlockSectionHeading
    | InputRichBlockPreformatted
    | InputRichBlockFooter
    | InputRichBlockDivider
    | InputRichBlockMathematicalExpression
    | InputRichBlockAnchor
    | InputRichBlockList
    | InputRichBlockBlockQuotation
    | InputRichBlockExpandableBlockQuotation
    | InputRichBlockPullQuotation
    | InputRichBlockCollage
    | InputRichBlockSlideshow
    | InputRichBlockTable
    | InputRichBlockDetails
    | InputRichBlockMap
    | InputRichBlockButtons
    | InputRichBlockAnimation
    | InputRichBlockAudio
    | InputRichBlockDocument
    | InputRichBlockPhoto
    | InputRichBlockVideo
    | InputRichBlockVoiceNote
    | InputRichBlockThinking,
    Field(discriminator="type"),
]



from .base import TelegramObject


class DisabledButton(TelegramObject):
    """
    This object represents a disabled button which does nothing. Currently holds no information.

    Source: https://core.telegram.org/bots/api#disabledbutton
    """



from typing import TYPE_CHECKING, Any

from .base import TelegramObject


class Community(TelegramObject):
    """
    Represents a community (a group of chats).

    Source: https://core.telegram.org/bots/api#community
    """

    id: int
    """Unique identifier for this community. This number may have more than 32 significant bits and some programming languages may have difficulty/silent defects in interpreting it. But it has at most 52 significant bits, so a signed 64-bit integer or double-precision float type are safe for storing this identifier"""
    name: str
    """Name of the community"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(__pydantic__self__, *, id: int, name: str, **__pydantic_kwargs: Any) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(id=id, name=name, **__pydantic_kwargs)



from __future__ import annotations

from typing import TYPE_CHECKING, Any, Literal

from ..enums import InputRichBlockType
from .base import TelegramObject
from .input_rich_block import InputRichBlock

if TYPE_CHECKING:
    from .input_media_voice_note import InputMediaVoiceNote
    from .rich_block_caption import RichBlockCaption


class InputRichBlockVoiceNote(InputRichBlock):
    """
    A block with a voice note, corresponding to the HTML tag :code:`<audio>`.

    Source: https://core.telegram.org/bots/api#inputrichblockvoicenote
    """

    type: Literal[InputRichBlockType.VOICE_NOTE] = InputRichBlockType.VOICE_NOTE
    """Type of the block, always 'voice_note'"""
    voice_note: InputMediaVoiceNote
    """The voice note. Caption is ignored"""
    caption: RichBlockCaption | None = None
    """*Optional*. Caption of the block"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            type: Literal[InputRichBlockType.VOICE_NOTE] = InputRichBlockType.VOICE_NOTE,
            voice_note: InputMediaVoiceNote,
            caption: RichBlockCaption | None = None,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(
                type=type, voice_note=voice_note, caption=caption, **__pydantic_kwargs
            )



from __future__ import annotations

from typing import TYPE_CHECKING, Any

from pydantic import Field

from ..client.default import Default
from ..types import (
    ChatIdUnion,
    EphemeralMessageParameters,
    InputFile,
    InputFileUnion,
    Message,
    MessageEntity,
    ReplyMarkupUnion,
    ReplyParameters,
    SuggestedPostParameters,
)
from .base import TelegramMethod


class SendAudio(TelegramMethod[Message]):
    """
    Use this method to send audio files, if you want Telegram clients to display them in the music player. Your audio must be in the .MP3 or .M4A format. On success, the sent :class:`aiogram.types.message.Message` is returned. Bots can currently send audio files of up to 50 MB in size, this limit may be changed in the future.
    For sending voice messages, use the :class:`aiogram.methods.send_voice.SendVoice` method instead.

    Source: https://core.telegram.org/bots/api#sendaudio
    """

    __returning__ = Message
    __api_method__ = "sendAudio"

    chat_id: ChatIdUnion
    """Unique identifier for the target chat or username of the target bot, supergroup or channel in the format :code:`@username`"""
    audio: InputFileUnion
    """Audio file to send. Pass a file_id as String to send an audio file that exists on the Telegram servers (recommended), pass an HTTP URL as a String for Telegram to get an audio file from the Internet, or upload a new one using multipart/form-data. :ref:`More information on Sending Files » <sending-files>`"""
    business_connection_id: str | None = None
    """Unique identifier of the business connection on behalf of which the message will be sent"""
    message_thread_id: int | None = None
    """Unique identifier for the target message thread (topic) of a forum; for forum supergroups and private chats of bots with forum topic mode enabled only"""
    direct_messages_topic_id: int | None = None
    """Identifier of the direct messages topic to which the message will be sent; required if the message is sent to a direct messages chat"""
    caption: str | None = None
    """Audio caption, 0-1024 characters after entities parsing"""
    parse_mode: str | Default | None = Default("parse_mode")
    """Mode for parsing entities in the audio caption. See `formatting options <https://core.telegram.org/bots/api#formatting-options>`_ for more details"""
    caption_entities: list[MessageEntity] | None = None
    """A JSON-serialized list of special entities that appear in the caption, which can be specified instead of *parse_mode*"""
    duration: int | None = None
    """Duration of the audio in seconds"""
    performer: str | None = None
    """Performer"""
    title: str | None = None
    """Track name"""
    thumbnail: InputFile | None = None
    """Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported server-side. The thumbnail should be in JPEG format and less than 200 kB in size. A thumbnail's width and height should not exceed 320. Ignored if the file is not uploaded using multipart/form-data. Thumbnails can't be reused and can be only uploaded as a new file, so you can pass 'attach://<file_attach_name>' if the thumbnail was uploaded using multipart/form-data under <file_attach_name>. :ref:`More information on Sending Files » <sending-files>`"""
    disable_notification: bool | None = None
    """Sends the message `silently <https://telegram.org/blog/channels-2-0#silent-messages>`_. Users will receive a notification with no sound"""
    protect_content: bool | Default | None = Default("protect_content")
    """Protects the contents of the sent message from forwarding and saving"""
    allow_paid_broadcast: bool | None = None
    """Pass :code:`True` to allow up to 1000 messages per second, ignoring `broadcasting limits <https://core.telegram.org/bots/faq#how-can-i-message-all-of-my-bot-39s-subscribers-at-once>`_ for a fee of 0.1 Telegram Stars per message. The relevant Stars will be withdrawn from the bot's balance"""
    message_effect_id: str | None = None
    """Unique identifier of the message effect to be added to the message; for private chats only"""
    suggested_post_parameters: SuggestedPostParameters | None = None
    """A JSON-serialized object containing the parameters of the suggested post to send; for direct messages chats only. If the message is sent as a reply to another suggested post, then that suggested post is automatically declined"""
    reply_parameters: ReplyParameters | None = None
    """Description of the message to reply to"""
    reply_markup: ReplyMarkupUnion | None = None
    """Additional interface options. A JSON-serialized object for an `inline keyboard <https://core.telegram.org/bots/features#inline-keyboards>`_, `custom reply keyboard <https://core.telegram.org/bots/features#keyboards>`_, instructions to remove a reply keyboard or to force a reply from the user"""
    ephemeral_message_parameters: EphemeralMessageParameters | None = None
    """A JSON-serialized object containing the parameters of the ephemeral message to send"""
    receiver_user_id: int | None = Field(None, json_schema_extra={"deprecated": True})
    """For outgoing ephemeral messages, unique identifier of the user who will receive the message; for group and supergroup chats only. It is not guaranteed that the user will receive the message, especially if they are offline. See `ephemeral message sending <https://core.telegram.org/bots/api#ephemeral-messages-and-commands>`_ for more details

.. deprecated:: API:10.3
   https://core.telegram.org/bots/api-changelog#august-24-2026"""
    callback_query_id: str | None = Field(None, json_schema_extra={"deprecated": True})
    """For outgoing ephemeral messages, identifier of the callback query which triggerred the message if any

.. deprecated:: API:10.3
   https://core.telegram.org/bots/api-changelog#august-24-2026"""
    allow_sending_without_reply: bool | None = Field(None, json_schema_extra={"deprecated": True})
    """Pass :code:`True` if the message should be sent even if the specified replied-to message is not found

.. deprecated:: API:7.0
   https://core.telegram.org/bots/api-changelog#december-29-2023"""
    reply_to_message_id: int | None = Field(None, json_schema_extra={"deprecated": True})
    """If the message is a reply, ID of the original message

.. deprecated:: API:7.0
   https://core.telegram.org/bots/api-changelog#december-29-2023"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            chat_id: ChatIdUnion,
            audio: InputFileUnion,
            business_connection_id: str | None = None,
            message_thread_id: int | None = None,
            direct_messages_topic_id: int | None = None,
            caption: str | None = None,
            parse_mode: str | Default | None = Default("parse_mode"),
            caption_entities: list[MessageEntity] | None = None,
            duration: int | None = None,
            performer: str | None = None,
            title: str | None = None,
            thumbnail: InputFile | None = None,
            disable_notification: bool | None = None,
            protect_content: bool | Default | None = Default("protect_content"),
            allow_paid_broadcast: bool | None = None,
            message_effect_id: str | None = None,
            suggested_post_parameters: SuggestedPostParameters | None = None,
            reply_parameters: ReplyParameters | None = None,
            reply_markup: ReplyMarkupUnion | None = None,
            ephemeral_message_parameters: EphemeralMessageParameters | None = None,
            receiver_user_id: int | None = None,
            callback_query_id: str | None = None,
            allow_sending_without_reply: bool | None = None,
            reply_to_message_id: int | None = None,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(
                chat_id=chat_id,
                audio=audio,
                business_connection_id=business_connection_id,
                message_thread_id=message_thread_id,
                direct_messages_topic_id=direct_messages_topic_id,
                caption=caption,
                parse_mode=parse_mode,
                caption_entities=caption_entities,
                duration=duration,
                performer=performer,
                title=title,
                thumbnail=thumbnail,
                disable_notification=disable_notification,
                protect_content=protect_content,
                allow_paid_broadcast=allow_paid_broadcast,
                message_effect_id=message_effect_id,
                suggested_post_parameters=suggested_post_parameters,
                reply_parameters=reply_parameters,
                reply_markup=reply_markup,
                ephemeral_message_parameters=ephemeral_message_parameters,
                receiver_user_id=receiver_user_id,
                callback_query_id=callback_query_id,
                allow_sending_without_reply=allow_sending_without_reply,
                reply_to_message_id=reply_to_message_id,
                **__pydantic_kwargs,
            )



from typing import TYPE_CHECKING, Any, Literal

from ..enums import RichBlockType
from .base import TelegramObject
from .rich_block import RichBlock


class RichBlockMathematicalExpression(RichBlock):
    """
    A block with a mathematical expression in LaTeX format, corresponding to the custom HTML tag :code:`<tg-math-block>`.

    Source: https://core.telegram.org/bots/api#richblockmathematicalexpression
    """

    type: Literal[RichBlockType.MATHEMATICAL_EXPRESSION] = RichBlockType.MATHEMATICAL_EXPRESSION
    """Type of the block, always 'mathematical_expression'"""
    expression: str
    """The mathematical expression in LaTeX format"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            type: Literal[
                RichBlockType.MATHEMATICAL_EXPRESSION
            ] = RichBlockType.MATHEMATICAL_EXPRESSION,
            expression: str,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(type=type, expression=expression, **__pydantic_kwargs)



from __future__ import annotations

from typing import TYPE_CHECKING, Any

from pydantic import Field

from ..client.default import Default
from ..types import (
    ChatIdUnion,
    EphemeralMessageParameters,
    InputFile,
    InputFileUnion,
    Message,
    ReplyMarkupUnion,
    ReplyParameters,
    SuggestedPostParameters,
)
from .base import TelegramMethod


class SendVideoNote(TelegramMethod[Message]):
    """
    Use this method to send a rounded square MPEG4 video of up to 1 minute long. On success, the sent :class:`aiogram.types.message.Message` is returned.

    Source: https://core.telegram.org/bots/api#sendvideonote
    """

    __returning__ = Message
    __api_method__ = "sendVideoNote"

    chat_id: ChatIdUnion
    """Unique identifier for the target chat or username of the target bot, supergroup or channel in the format :code:`@username`"""
    video_note: InputFileUnion
    """Video note to send. Pass a file_id as String to send a video note that exists on the Telegram servers (recommended) or upload a new video using multipart/form-data. :ref:`More information on Sending Files » <sending-files>`. Sending video notes by a URL is currently unsupported"""
    business_connection_id: str | None = None
    """Unique identifier of the business connection on behalf of which the message will be sent"""
    message_thread_id: int | None = None
    """Unique identifier for the target message thread (topic) of a forum; for forum supergroups and private chats of bots with forum topic mode enabled only"""
    direct_messages_topic_id: int | None = None
    """Identifier of the direct messages topic to which the message will be sent; required if the message is sent to a direct messages chat"""
    duration: int | None = None
    """Duration of sent video in seconds"""
    length: int | None = None
    """Video width and height, i.e. diameter of the video message"""
    thumbnail: InputFile | None = None
    """Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported server-side. The thumbnail should be in JPEG format and less than 200 kB in size. A thumbnail's width and height should not exceed 320. Ignored if the file is not uploaded using multipart/form-data. Thumbnails can't be reused and can be only uploaded as a new file, so you can pass 'attach://<file_attach_name>' if the thumbnail was uploaded using multipart/form-data under <file_attach_name>. :ref:`More information on Sending Files » <sending-files>`"""
    disable_notification: bool | None = None
    """Sends the message `silently <https://telegram.org/blog/channels-2-0#silent-messages>`_. Users will receive a notification with no sound"""
    protect_content: bool | Default | None = Default("protect_content")
    """Protects the contents of the sent message from forwarding and saving"""
    allow_paid_broadcast: bool | None = None
    """Pass :code:`True` to allow up to 1000 messages per second, ignoring `broadcasting limits <https://core.telegram.org/bots/faq#how-can-i-message-all-of-my-bot-39s-subscribers-at-once>`_ for a fee of 0.1 Telegram Stars per message. The relevant Stars will be withdrawn from the bot's balance"""
    message_effect_id: str | None = None
    """Unique identifier of the message effect to be added to the message; for private chats only"""
    suggested_post_parameters: SuggestedPostParameters | None = None
    """A JSON-serialized object containing the parameters of the suggested post to send; for direct messages chats only. If the message is sent as a reply to another suggested post, then that suggested post is automatically declined"""
    reply_parameters: ReplyParameters | None = None
    """Description of the message to reply to"""
    reply_markup: ReplyMarkupUnion | None = None
    """Additional interface options. A JSON-serialized object for an `inline keyboard <https://core.telegram.org/bots/features#inline-keyboards>`_, `custom reply keyboard <https://core.telegram.org/bots/features#keyboards>`_, instructions to remove a reply keyboard or to force a reply from the user"""
    ephemeral_message_parameters: EphemeralMessageParameters | None = None
    """A JSON-serialized object containing the parameters of the ephemeral message to send"""
    receiver_user_id: int | None = Field(None, json_schema_extra={"deprecated": True})
    """For outgoing ephemeral messages, unique identifier of the user who will receive the message; for group and supergroup chats only. It is not guaranteed that the user will receive the message, especially if they are offline. See `ephemeral message sending <https://core.telegram.org/bots/api#ephemeral-messages-and-commands>`_ for more details

.. deprecated:: API:10.3
   https://core.telegram.org/bots/api-changelog#august-24-2026"""
    callback_query_id: str | None = Field(None, json_schema_extra={"deprecated": True})
    """For outgoing ephemeral messages, identifier of the callback query which triggerred the message if any

.. deprecated:: API:10.3
   https://core.telegram.org/bots/api-changelog#august-24-2026"""
    allow_sending_without_reply: bool | None = Field(None, json_schema_extra={"deprecated": True})
    """Pass :code:`True` if the message should be sent even if the specified replied-to message is not found

.. deprecated:: API:7.0
   https://core.telegram.org/bots/api-changelog#december-29-2023"""
    reply_to_message_id: int | None = Field(None, json_schema_extra={"deprecated": True})
    """If the message is a reply, ID of the original message

.. deprecated:: API:7.0
   https://core.telegram.org/bots/api-changelog#december-29-2023"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            chat_id: ChatIdUnion,
            video_note: InputFileUnion,
            business_connection_id: str | None = None,
            message_thread_id: int | None = None,
            direct_messages_topic_id: int | None = None,
            duration: int | None = None,
            length: int | None = None,
            thumbnail: InputFile | None = None,
            disable_notification: bool | None = None,
            protect_content: bool | Default | None = Default("protect_content"),
            allow_paid_broadcast: bool | None = None,
            message_effect_id: str | None = None,
            suggested_post_parameters: SuggestedPostParameters | None = None,
            reply_parameters: ReplyParameters | None = None,
            reply_markup: ReplyMarkupUnion | None = None,
            ephemeral_message_parameters: EphemeralMessageParameters | None = None,
            receiver_user_id: int | None = None,
            callback_query_id: str | None = None,
            allow_sending_without_reply: bool | None = None,
            reply_to_message_id: int | None = None,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(
                chat_id=chat_id,
                video_note=video_note,
                business_connection_id=business_connection_id,
                message_thread_id=message_thread_id,
                direct_messages_topic_id=direct_messages_topic_id,
                duration=duration,
                length=length,
                thumbnail=thumbnail,
                disable_notification=disable_notification,
                protect_content=protect_content,
                allow_paid_broadcast=allow_paid_broadcast,
                message_effect_id=message_effect_id,
                suggested_post_parameters=suggested_post_parameters,
                reply_parameters=reply_parameters,
                reply_markup=reply_markup,
                ephemeral_message_parameters=ephemeral_message_parameters,
                receiver_user_id=receiver_user_id,
                callback_query_id=callback_query_id,
                allow_sending_without_reply=allow_sending_without_reply,
                reply_to_message_id=reply_to_message_id,
                **__pydantic_kwargs,
            )



from __future__ import annotations

from typing import TYPE_CHECKING, Any

from .base import TelegramObject

if TYPE_CHECKING:
    from .user import User


class BotSubscriptionUpdated(TelegramObject):
    """
    This object contains information about changes to a user payment subscription toward the current bot.

    Source: https://core.telegram.org/bots/api#botsubscriptionupdated
    """

    user: User
    """User who subscribed for payments toward the bot"""
    invoice_payload: str
    """Bot-specified invoice payload"""
    state: str
    """The new state of the subscription. Currently, it can be one of 'canceled' if the user canceled the subscription, 'active' if the user re-enabled a previously canceled subscription, or 'failed' if payment for the subscription failed"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            user: User,
            invoice_payload: str,
            state: str,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(
                user=user, invoice_payload=invoice_payload, state=state, **__pydantic_kwargs
            )
